# mediaApiClient
Публичная библиотека для работы c API ContentApiGate, написанная на python.

## Installation

Установка последней версии mediaApiClient - [PyPI](https://pypi.org/project/mediaApiClient/):

```bash
pip install mediaApiClient
```

## Документация по отдельным контроллерам

* Controllers
  * [Работа с Content Controller](docs/content.md)
  * [Работа с Stream Controller](docs/stream.md)
  * [Работа с Service Controller](docs/service.md)
  * [Работа с Account Controller](docs/account.md)
  * [Работа с Compilation Controller](docs/compilation.md)

## Лицензия

[Apache License, Version 2.0](https://opensource.org/licenses/Apache-2.0)